%global _python_bytecompile_extra   0

Name:           powerline
Version:        2.8.3
Release:        %mkrel 1

Summary:        The ultimate status-line/prompt utility
License:        MIT
Group:          System/Base
Url:            https://github.com/powerline/powerline

BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
BuildRequires:  python3-devel
BuildRequires:  fdupes
BuildRequires:  fontconfig
BuildRequires:  systemd
# for macro definition:
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  tmux
BuildRequires:  vim-minimal

Requires:       python3
Requires:       powerline-fonts
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Recommends:     python3-pygit2

Source0:        https://github.com/powerline/powerline/archive/%{version}/powerline-%{version}.tar.gz
Source1:        vim-powerline.metainfo.xml

%description
Powerline is a status-line plugin for vim, and provides status-lines and prompts
for several other applications, including zsh, bash, tmux, IPython, Awesome and
Qtile.

%package docs
Summary: Powerline Documentation
Group: Documentation
BuildArch: noarch

%description docs
This package provides the powerline documentation.

%package fonts
Summary: Powerline Fonts
BuildArch: noarch
Requires: fontconfig

%description fonts
This package provides the powerline fonts.

%package -n vim-powerline
Summary: Powerline VIM plugin
Group: Editors
BuildArch: noarch
Requires: vim
Requires: %{name} = %{version}-%{release}
Obsoletes: vim-plugin-powerline < %{version}-%{release}
Provides: vim-plugin-powerline = %{version}-%{release}

%description -n vim-powerline
Powerline is a status-line plugin for vim, and provides status-lines and
prompts.

%package -n tmux-powerline
Summary: Powerline for tmux
Group: System/Base
BuildArch: noarch
Requires: tmux
Requires: %{name} = %{version}-%{release}

%description -n tmux-powerline
Powerline for tmux.

Add

    source /usr/share/tmux/powerline.conf

to your ~/.tmux.conf file.

%prep
%autosetup -p1
find -type f -exec sed -i '1s=^#!/usr/bin/\(python\|env python\)[23]\?=#!%{__python3}=' {} +

%build
# nothing to build

%install
sed -i -e "/DEFAULT_SYSTEM_CONFIG_DIR/ s@None@'%{_sysconfdir}/xdg'@" powerline/config.py
sed -i -e "/TMUX_CONFIG_DIRECTORY/ s@BINDINGS_DIRECTORY@'/usr/share'@" powerline/config.py
# `setup.py` uses `CFLAGS` for both compiler and linker flags
CFLAGS="%{build_cflags} %{build_ldflags}" \
%{__python3} setup.py install --prefix=%{_prefix} --root=%{buildroot} --optimize=1

# Check that the powerline client is an ELF executable
ldd %{buildroot}%{_bindir}/powerline

# build docs
pushd docs
%__make html SPHINXBUILD=/usr/bin/sphinx-build-3
%__rm _build/html/.buildinfo
# A structure gets initialized while building the docs with os.environ.
# This works around an rpmlint error with the build dir being in a file.
sed -i -e 's/abuild/user/g' _build/html/develop/extensions.html

%__make man SPHINXBUILD=/usr/bin/sphinx-build-3
popd

# config
install -d -m0755 %{buildroot}%{_sysconfdir}/xdg/%{name}
cp -a powerline/config_files/* %{buildroot}%{_sysconfdir}/xdg/%{name}/

# fonts
install -d -m0755 %{buildroot}%{_sysconfdir}/fonts/conf.d
install -d -m0755 %{buildroot}%{_datadir}/fonts/truetype
install -d -m0755 %{buildroot}%{_datadir}/fontconfig/conf.avail

install -m0644 font/PowerlineSymbols.otf %{buildroot}%{_datadir}/fonts/truetype/PowerlineSymbols.otf
install -m0644 font/10-powerline-symbols.conf %{buildroot}%{_datadir}/fontconfig/conf.avail/10-powerline-symbols.conf

ln -sr %{buildroot}%{_datadir}/fontconfig/conf.avail/10-powerline-symbols.conf %{buildroot}%{_sysconfdir}/fonts/conf.d/10-powerline-symbols.conf

# manpages
%__install -d -m0755 %{buildroot}%{_datadir}/man/man1
for f in powerline-config.1 powerline-daemon.1 powerline-lint.1 powerline.1; do
%__install -m0644 docs/_build/man/$f %{buildroot}%{_datadir}/man/man1/$f
done

# awesome
install -d -m0755 %{buildroot}%{_datadir}/%{name}/awesome/
mv %{buildroot}%{python3_sitelib}/powerline/bindings/awesome/powerline.lua %{buildroot}%{_datadir}/%{name}/awesome/
mv %{buildroot}%{python3_sitelib}/powerline/bindings/awesome/powerline-awesome.py %{buildroot}%{_datadir}/%{name}/awesome/

# bash bindings
install -d -m0755 %{buildroot}%{_datadir}/%{name}/bash
mv %{buildroot}%{python3_sitelib}/powerline/bindings/bash/powerline.sh %{buildroot}%{_datadir}/%{name}/bash/

# fish
install -d -m0755 %{buildroot}%{_datadir}/%{name}/fish
mv %{buildroot}%{python3_sitelib}/powerline/bindings/fish/powerline-setup.fish %{buildroot}%{_datadir}/%{name}/fish

# i3
install -d -m0755 %{buildroot}%{_datadir}/%{name}/i3
mv %{buildroot}%{python3_sitelib}/powerline/bindings/i3/powerline-i3.py %{buildroot}%{_datadir}/%{name}/i3

# qtile
install -d -m0755 %{buildroot}%{_datadir}/%{name}/qtile
mv %{buildroot}%{python3_sitelib}/powerline/bindings/qtile/widget.py %{buildroot}%{_datadir}/%{name}/qtile

# shell bindings
install -d -m0755 %{buildroot}%{_datadir}/%{name}/shell
mv %{buildroot}%{python3_sitelib}/powerline/bindings/shell/powerline.sh %{buildroot}%{_datadir}/%{name}/shell/

# tcsh
install -d -m0755 %{buildroot}%{_datadir}/%{name}/tcsh
mv %{buildroot}%{python3_sitelib}/powerline/bindings/tcsh/powerline.tcsh %{buildroot}%{_datadir}/%{name}/tcsh

# tmux plugin
install -d -m0755 %{buildroot}%{_datadir}/tmux
mv %{buildroot}%{python3_sitelib}/powerline/bindings/tmux/powerline*.conf %{buildroot}%{_datadir}/tmux/

# vim plugin
install -d -m0755 %{buildroot}%{_datadir}/vim/vimfiles/plugin/
mv %{buildroot}%{python3_sitelib}/powerline/bindings/vim/plugin/powerline.vim %{buildroot}%{_datadir}/vim/vimfiles/plugin/powerline.vim
rm -rf %{buildroot}%{python3_sitelib}/powerline/bindings/vim/plugin
install -d -m0755 %{buildroot}%{_datadir}/vim/vimfiles/autoload/powerline
mv %{buildroot}%{python3_sitelib}/powerline/bindings/vim/autoload/powerline/debug.vim %{buildroot}%{_datadir}/vim/vimfiles/autoload/powerline/debug.vim
rm -rf %{buildroot}%{python3_sitelib}/powerline/bindings/vim/autoload

# zsh
install -d -m0755 %{buildroot}%{_datadir}/%{name}/zsh
mv %{buildroot}%{python3_sitelib}/powerline/bindings/zsh/__init__.py %{buildroot}%{_datadir}/%{name}/zsh
mv %{buildroot}%{python3_sitelib}/powerline/bindings/zsh/powerline.zsh %{buildroot}%{_datadir}/%{name}/zsh

# vim-powerline appdata
mkdir -p %{buildroot}%{_datadir}/appdata
install -m 644 %{SOURCE1} %{buildroot}%{_datadir}/appdata

# systemd
install -d -m 0755 %{buildroot}%{_userunitdir}
install -m 0644 powerline/dist/systemd/powerline-daemon.service %{buildroot}%{_userunitdir}/powerline.service

# cleanup
%__rm -rf %{buildroot}%{python3_sitelib}/%{name}/config_files

%fdupes %{buildroot}%{python3_sitelib}

%post
%systemd_user_post powerline.service

%preun
%systemd_user_preun powerline.service

%postun
%systemd_user_postun_with_restart powerline.service

%files
%license LICENSE
%doc README.rst
%config(noreplace) %{_sysconfdir}/xdg/%{name}
%{_bindir}/powerline
%{_bindir}/powerline-config
%{_bindir}/powerline-daemon
%{_bindir}/powerline-render
%{_bindir}/powerline-lint
%{_mandir}/man1/powerline.1*
%{_mandir}/man1/powerline-config.1*
%{_mandir}/man1/powerline-daemon.1*
%{_mandir}/man1/powerline-lint.1*
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/awesome
%{_datadir}/%{name}/awesome/powerline.lua
%{_datadir}/%{name}/awesome/powerline-awesome.py*
%dir %{_datadir}/%{name}/bash
%{_datadir}/%{name}/bash/powerline.sh
%dir %{_datadir}/%{name}/fish
%{_datadir}/%{name}/fish/powerline-setup.fish
%dir %{_datadir}/%{name}/i3
%{_datadir}/%{name}/i3/powerline-i3.py*
%dir %{_datadir}/%{name}/qtile
%{_datadir}/%{name}/qtile/widget.py*
%dir %{_datadir}/%{name}/shell
%{_datadir}/%{name}/shell/powerline.sh
%dir %{_datadir}/%{name}/tcsh
%{_datadir}/%{name}/tcsh/powerline.tcsh
%dir %{_datadir}/%{name}/zsh
%{_datadir}/%{name}/zsh/__init__.py*
%{_datadir}/%{name}/zsh/powerline.zsh
%{python3_sitelib}/*
%{_userunitdir}/powerline.service

%files docs
%doc docs/_build/html

%files fonts
%doc LICENSE README.rst
%{_sysconfdir}/fonts/conf.d/10-powerline-symbols.conf
%{_datadir}/fontconfig/conf.avail/10-powerline-symbols.conf
%dir %{_datadir}/fonts/truetype
%{_datadir}/fonts/truetype/PowerlineSymbols.otf

%files -n vim-powerline
%doc LICENSE README.rst
%dir %{_datadir}/vim/vimfiles
%dir %{_datadir}/vim/vimfiles/autoload
%dir %{_datadir}/vim/vimfiles/autoload/powerline
%{_datadir}/vim/vimfiles/autoload/powerline/debug.vim
%dir %{_datadir}/vim/vimfiles/plugin
%{_datadir}/vim/vimfiles/plugin/powerline.vim
%{_datadir}/appdata/vim-powerline.metainfo.xml

%files -n tmux-powerline
%doc LICENSE README.rst
%dir %{_datadir}/tmux
%{_datadir}/tmux/powerline*.conf



%changelog
* Wed Jun 29 2022 tv <tv> 2.8.3-1.mga9
+ Revision: 1866599
- Update to 2.8.3
- Install `powerline-daemon.service` into systemd user directory (rhbz#1976191)
- Build `powerline` binary with correct linker flags
- Make Fontconfig symlink relative

* Wed Mar 30 2022 umeabot <umeabot> 2.8.2-3.mga9
+ Revision: 1834354
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tv <tv> 2.8.2-2.mga9
+ Revision: 1774625
- Rebuild for python-3.10

* Tue Aug 03 2021 luigiwalser <luigiwalser> 2.8.2-1.mga9
+ Revision: 1738787
- 2.8.2

* Sat Mar 20 2021 tv <tv> 2.8-3.mga9
+ Revision: 1705613
- rebuild for python-3.9.2

* Sat Mar 20 2021 tv <tv> 2.8-2.mga9
+ Revision: 1705573
- rebuild for python-3.9.2

* Sun Sep 20 2020 tv <tv> 2.8-1.mga8
+ Revision: 1628904
- 2.8

* Sun Feb 16 2020 umeabot <umeabot> 2.7-3.mga8
+ Revision: 1531425
- Mageia 8 Mass Rebuild

* Fri Sep 13 2019 tv <tv> 2.7-2.mga8
+ Revision: 1440261
- disable %%_python_bytecompile_extra
- rebuild for python-3.8

* Thu Jan 10 2019 tv <tv> 2.7-1.mga7
+ Revision: 1354203
- new release

* Tue Jan 08 2019 tv <tv> 2.6-4.mga7
+ Revision: 1351797
- rebuild with python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 2.6-3.mga7
+ Revision: 1300357
- Mageia 7 Mass Rebuild

* Thu Aug 10 2017 tv <tv> 2.6-2.mga7
+ Revision: 1139522
- actually apply all patches

* Thu Aug 10 2017 tv <tv> 2.6-1.mga7
+ Revision: 1139521
- new release

* Fri Aug 04 2017 tv <tv> 2.5-4.mga7
+ Revision: 1134568
- rebuild for new python

* Fri Nov 11 2016 ngompa <ngompa> 2.5-3.mga6
+ Revision: 1066444
- Clean up spec

* Sun Oct 16 2016 tv <tv> 2.5-2.mga6
+ Revision: 1061152
- BR systemd-devel for macro definition (mga#12027)

* Thu Sep 15 2016 tv <tv> 2.5-1.mga6
+ Revision: 1052991
- imported package powerline

